@@ -1,7 +1,10 @@
 import sys
 
+from sentry_sdk._compat import PY2, reraise
 from sentry_sdk._functools import partial
+from sentry_sdk._types import TYPE_CHECKING
 from sentry_sdk._werkzeug import get_host, _get_headers
+from sentry_sdk.api import continue_trace
 from sentry_sdk.consts import OP
 from sentry_sdk.hub import Hub, _should_send_default_pii
 from sentry_sdk.utils import (
@@ -9,13 +12,10 @@ from sentry_sdk.utils import (
     capture_internal_exceptions,
     event_from_exception,
 )
-from sentry_sdk._compat import PY2, reraise
 from sentry_sdk.tracing import Transaction, TRANSACTION_SOURCE_ROUTE
 from sentry_sdk.sessions import auto_session_tracking
 from sentry_sdk.integrations._wsgi_common import _filter_headers
 
-from sentry_sdk._types import TYPE_CHECKING
-
 if TYPE_CHECKING:
     from typing import Callable
     from typing import Dict
@@ -27,7 +27,7 @@ if TYPE_CHECKING:
     from typing import Protocol
 
     from sentry_sdk.utils import ExcInfo
-    from sentry_sdk._types import EventProcessor
+    from sentry_sdk._types import Event, EventProcessor
 
     WsgiResponseIter = TypeVar("WsgiResponseIter")
     WsgiResponseHeaders = TypeVar("WsgiResponseHeaders")
@@ -94,7 +94,7 @@ class SentryWsgiMiddleware(object):
                                 )
                             )
 
-                    transaction = Transaction.continue_from_environ(
+                    transaction = continue_trace(
                         environ,
                         op=OP.HTTP_SERVER,
                         name="generic WSGI request",
@@ -254,7 +254,7 @@ def _make_wsgi_event_processor(environ, use_x_forwarded_for):
     headers = _filter_headers(dict(_get_headers(environ)))
 
     def event_processor(event, hint):
-        # type: (Dict[str, Any], Dict[str, Any]) -> Dict[str, Any]
+        # type: (Event, Dict[str, Any]) -> Event
         with capture_internal_exceptions():
             # if the code below fails halfway through we at least have some data
             request_info = event.setdefault("request", {})
