@@ -58,7 +58,7 @@ def parse_metrics(bytes):
 
 @minimum_python_37_with_gevent
 @pytest.mark.forked
-def test_incr(sentry_init, capture_envelopes, maybe_monkeypatched_threading):
+def test_increment(sentry_init, capture_envelopes, maybe_monkeypatched_threading):
     sentry_init(
         release="fun-release",
         environment="not-fun-env",
@@ -67,7 +67,8 @@ def test_incr(sentry_init, capture_envelopes, maybe_monkeypatched_threading):
     ts = time.time()
     envelopes = capture_envelopes()
 
-    metrics.incr("foobar", 1.0, tags={"foo": "bar", "blub": "blah"}, timestamp=ts)
+    metrics.increment("foobar", 1.0, tags={"foo": "bar", "blub": "blah"}, timestamp=ts)
+    # python specific alias
     metrics.incr("foobar", 2.0, tags={"foo": "bar", "blub": "blah"}, timestamp=ts)
     Hub.current.flush()
 
@@ -487,8 +488,8 @@ def test_multiple(sentry_init, capture_envelopes):
     metrics.gauge("my-gauge", 20.0, tags={"x": "y"}, timestamp=ts)
     metrics.gauge("my-gauge", 30.0, tags={"x": "y"}, timestamp=ts)
     for _ in range(10):
-        metrics.incr("counter-1", 1.0, timestamp=ts)
-    metrics.incr("counter-2", 1.0, timestamp=ts)
+        metrics.increment("counter-1", 1.0, timestamp=ts)
+    metrics.increment("counter-2", 1.0, timestamp=ts)
 
     Hub.current.flush()
 
@@ -570,18 +571,13 @@ def test_transaction_name(
 
 @minimum_python_37_with_gevent
 @pytest.mark.forked
-@pytest.mark.parametrize("sample_rate", [1.0, None])
 def test_metric_summaries(
-    sentry_init, capture_envelopes, sample_rate, maybe_monkeypatched_threading
+    sentry_init, capture_envelopes, maybe_monkeypatched_threading
 ):
     sentry_init(
         release="fun-release@1.0.0",
         environment="not-fun-env",
         enable_tracing=True,
-        _experiments={
-            "enable_metrics": True,
-            "metrics_summary_sample_rate": sample_rate,
-        },
     )
     ts = time.time()
     envelopes = capture_envelopes()
@@ -589,7 +585,7 @@ def test_metric_summaries(
     with start_transaction(
         op="stuff", name="/foo", source=TRANSACTION_SOURCE_ROUTE
     ) as transaction:
-        metrics.incr("root-counter", timestamp=ts)
+        metrics.increment("root-counter", timestamp=ts)
         with metrics.timing("my-timer-metric", tags={"a": "b"}, timestamp=ts):
             for x in range(10):
                 metrics.distribution("my-dist", float(x), timestamp=ts)
@@ -681,171 +677,99 @@ def test_metric_summaries(
 
 @minimum_python_37_with_gevent
 @pytest.mark.forked
-def test_metrics_summary_disabled(
-    sentry_init, capture_envelopes, maybe_monkeypatched_threading
+@pytest.mark.parametrize(
+    "metric_name,metric_unit,expected_name",
+    [
+        ("first-metric", "nano-second", "first-metric@nanosecond"),
+        ("another_metric?", "nano second", "another_metric_@nanosecond"),
+        (
+            "metric",
+            "nanosecond",
+            "metric@nanosecond",
+        ),
+        (
+            "my.amaze.metric I guess",
+            "nano|\nsecond",
+            "my.amaze.metric_I_guess@nanosecond",
+        ),
+        # fmt: off
+        (u"métríc", u"nanöseconď", u"m_tr_c@nansecon"),
+        # fmt: on
+    ],
+)
+def test_metric_name_normalization(
+    sentry_init,
+    capture_envelopes,
+    metric_name,
+    metric_unit,
+    expected_name,
+    maybe_monkeypatched_threading,
 ):
     sentry_init(
-        release="fun-release@1.0.0",
-        environment="not-fun-env",
-        enable_tracing=True,
-        _experiments={"enable_metrics": True, "metrics_summary_sample_rate": 0.0},
-    )
-    ts = time.time()
-    envelopes = capture_envelopes()
-
-    with start_transaction(
-        op="stuff", name="/foo", source=TRANSACTION_SOURCE_ROUTE
-    ) as transaction:
-        with metrics.timing("my-timer-metric", tags={"a": "b"}, timestamp=ts):
-            pass
-
-    Hub.current.flush()
-
-    (transaction, envelope) = envelopes
-
-    # Metrics Emission
-    assert envelope.items[0].headers["type"] == "statsd"
-    m = parse_metrics(envelope.items[0].payload.get_bytes())
-
-    assert len(m) == 1
-    assert m[0][1] == "my-timer-metric@second"
-    assert m[0][2] == "d"
-    assert len(m[0][3]) == 1
-    assert m[0][4] == {
-        "a": "b",
-        "transaction": "/foo",
-        "release": "fun-release@1.0.0",
-        "environment": "not-fun-env",
-    }
-
-    # Measurement Attachment
-    t = transaction.items[0].get_transaction_event()
-    assert "_metrics_summary" not in t
-    assert "_metrics_summary" not in t["spans"][0]
-
-
-@minimum_python_37_with_gevent
-@pytest.mark.forked
-def test_metrics_summary_filtered(
-    sentry_init, capture_envelopes, maybe_monkeypatched_threading
-):
-    def should_summarize_metric(key, tags):
-        return key == "foo"
-
-    sentry_init(
-        release="fun-release@1.0.0",
-        environment="not-fun-env",
-        enable_tracing=True,
-        _experiments={
-            "enable_metrics": True,
-            "metrics_summary_sample_rate": 1.0,
-            "should_summarize_metric": should_summarize_metric,
-        },
-    )
-    ts = time.time()
-    envelopes = capture_envelopes()
-
-    with start_transaction(
-        op="stuff", name="/foo", source=TRANSACTION_SOURCE_ROUTE
-    ) as transaction:
-        metrics.timing("foo", value=3.0, tags={"a": "b"}, timestamp=ts)
-        metrics.timing("foo", value=2.0, tags={"b": "c"}, timestamp=ts)
-        metrics.timing("bar", value=1.0, tags={"a": "b"}, timestamp=ts)
-
-    Hub.current.flush()
-
-    (transaction, envelope) = envelopes
-
-    # Metrics Emission
-    assert envelope.items[0].headers["type"] == "statsd"
-    m = parse_metrics(envelope.items[0].payload.get_bytes())
-
-    assert len(m) == 3
-    assert m[0][1] == "bar@second"
-    assert m[1][1] == "foo@second"
-    assert m[2][1] == "foo@second"
-
-    # Measurement Attachment
-    t = transaction.items[0].get_transaction_event()["_metrics_summary"]
-    assert len(t["d:foo@second"]) == 2
-    assert {
-        "tags": {
-            "a": "b",
-            "environment": "not-fun-env",
-            "release": "fun-release@1.0.0",
-            "transaction": "/foo",
-        },
-        "min": 3.0,
-        "max": 3.0,
-        "count": 1,
-        "sum": 3.0,
-    } in t["d:foo@second"]
-    assert {
-        "tags": {
-            "b": "c",
-            "environment": "not-fun-env",
-            "release": "fun-release@1.0.0",
-            "transaction": "/foo",
-        },
-        "min": 2.0,
-        "max": 2.0,
-        "count": 1,
-        "sum": 2.0,
-    } in t["d:foo@second"]
-
-
-@minimum_python_37_with_gevent
-@pytest.mark.forked
-def test_tag_normalization(
-    sentry_init, capture_envelopes, maybe_monkeypatched_threading
-):
-    sentry_init(
-        release="fun-release@1.0.0",
-        environment="not-fun-env",
         _experiments={"enable_metrics": True, "metric_code_locations": False},
     )
-    ts = time.time()
     envelopes = capture_envelopes()
 
-    # fmt: off
-    metrics.distribution("a", 1.0, tags={"foo-bar": "%$foo"}, timestamp=ts)
-    metrics.distribution("b", 1.0, tags={"foo$$$bar": "blah{}"}, timestamp=ts)
-    metrics.distribution("c", 1.0, tags={u"foö-bar": u"snöwmän"}, timestamp=ts)
-    metrics.distribution("d", 1.0, tags={"route": "GET /foo"}, timestamp=ts)
-    # fmt: on
+    metrics.distribution(metric_name, 1.0, unit=metric_unit)
+
     Hub.current.flush()
 
     (envelope,) = envelopes
 
     assert len(envelope.items) == 1
     assert envelope.items[0].headers["type"] == "statsd"
-    m = parse_metrics(envelope.items[0].payload.get_bytes())
 
-    assert len(m) == 4
-    assert m[0][4] == {
-        "foo-bar": "$foo",
-        "release": "fun-release@1.0.0",
-        "environment": "not-fun-env",
-    }
+    parsed_metrics = parse_metrics(envelope.items[0].payload.get_bytes())
+    assert len(parsed_metrics) == 1
 
-    assert m[1][4] == {
-        "foo_bar": "blah{}",
-        "release": "fun-release@1.0.0",
-        "environment": "not-fun-env",
-    }
+    name = parsed_metrics[0][1]
+    assert name == expected_name
 
-    # fmt: off
-    assert m[2][4] == {
-        "fo_-bar": u"snöwmän",
-        "release": "fun-release@1.0.0",
-        "environment": "not-fun-env",
-    }
-    assert m[3][4] == {
-        "release": "fun-release@1.0.0",
-        "environment": "not-fun-env",
-        "route": "GET /foo",
-    }
-    # fmt: on
+
+@minimum_python_37_with_gevent
+@pytest.mark.forked
+@pytest.mark.parametrize(
+    "metric_tag,expected_tag",
+    [
+        ({"f-oo|bar": "%$foo/"}, {"f-oobar": "%$foo/"}),
+        ({"foo$.$.$bar": "blah{}"}, {"foo..bar": "blah{}"}),
+        # fmt: off
+        ({u"foö-bar": u"snöwmän"}, {u"fo-bar": u"snöwmän"},),
+        # fmt: on
+        ({"route": "GET /foo"}, {"route": "GET /foo"}),
+        ({"__bar__": "this | or , that"}, {"__bar__": "this \\u{7c} or \\u{2c} that"}),
+        ({"foo/": "hello!\n\r\t\\"}, {"foo/": "hello!\\n\\r\\t\\\\"}),
+    ],
+)
+def test_metric_tag_normalization(
+    sentry_init,
+    capture_envelopes,
+    metric_tag,
+    expected_tag,
+    maybe_monkeypatched_threading,
+):
+    sentry_init(
+        _experiments={"enable_metrics": True, "metric_code_locations": False},
+    )
+    envelopes = capture_envelopes()
+
+    metrics.distribution("a", 1.0, tags=metric_tag)
+
+    Hub.current.flush()
+
+    (envelope,) = envelopes
+
+    assert len(envelope.items) == 1
+    assert envelope.items[0].headers["type"] == "statsd"
+
+    parsed_metrics = parse_metrics(envelope.items[0].payload.get_bytes())
+    assert len(parsed_metrics) == 1
+
+    tags = parsed_metrics[0][4]
+
+    expected_tag_key, expected_tag_value = expected_tag.popitem()
+    assert expected_tag_key in tags
+    assert tags[expected_tag_key] == expected_tag_value
 
 
 @minimum_python_37_with_gevent
@@ -853,13 +777,14 @@ def test_tag_normalization(
 def test_before_emit_metric(
     sentry_init, capture_envelopes, maybe_monkeypatched_threading
 ):
-    def before_emit(key, tags):
-        if key == "removed-metric":
+    def before_emit(key, value, unit, tags):
+        if key == "removed-metric" or value == 47 or unit == "unsupported":
             return False
+
         tags["extra"] = "foo"
         del tags["release"]
         # this better be a noop!
-        metrics.incr("shitty-recursion")
+        metrics.increment("shitty-recursion")
         return True
 
     sentry_init(
@@ -873,8 +798,10 @@ def test_before_emit_metric(
     )
     envelopes = capture_envelopes()
 
-    metrics.incr("removed-metric", 1.0)
-    metrics.incr("actual-metric", 1.0)
+    metrics.increment("removed-metric", 1.0)
+    metrics.increment("another-removed-metric", 47)
+    metrics.increment("yet-another-removed-metric", 1.0, unit="unsupported")
+    metrics.increment("actual-metric", 1.0)
     Hub.current.flush()
 
     (envelope,) = envelopes
@@ -906,7 +833,7 @@ def test_aggregator_flush(
     )
     envelopes = capture_envelopes()
 
-    metrics.incr("a-metric", 1.0)
+    metrics.increment("a-metric", 1.0)
     Hub.current.flush()
 
     assert len(envelopes) == 1
@@ -925,7 +852,7 @@ def test_tag_serialization(
     )
     envelopes = capture_envelopes()
 
-    metrics.incr(
+    metrics.increment(
         "counter",
         tags={
             "no-value": None,
@@ -970,12 +897,12 @@ def test_flush_recursion_protection(
     real_capture_envelope = test_client.transport.capture_envelope
 
     def bad_capture_envelope(*args, **kwargs):
-        metrics.incr("bad-metric")
+        metrics.increment("bad-metric")
         return real_capture_envelope(*args, **kwargs)
 
     monkeypatch.setattr(test_client.transport, "capture_envelope", bad_capture_envelope)
 
-    metrics.incr("counter")
+    metrics.increment("counter")
 
     # flush twice to see the inner metric
     Hub.current.flush()
@@ -1004,12 +931,12 @@ def test_flush_recursion_protection_background_flush(
     real_capture_envelope = test_client.transport.capture_envelope
 
     def bad_capture_envelope(*args, **kwargs):
-        metrics.incr("bad-metric")
+        metrics.increment("bad-metric")
         return real_capture_envelope(*args, **kwargs)
 
     monkeypatch.setattr(test_client.transport, "capture_envelope", bad_capture_envelope)
 
-    metrics.incr("counter")
+    metrics.increment("counter")
 
     # flush via sleep and flag
     Hub.current.client.metrics_aggregator._force_flush = True
